import React from 'react';
import { TagProps } from '@highlight-ui/tag';
import { InputProps } from '@highlight-ui/input';
import { PropsWithMetadata, noop } from '@highlight-ui/utils-commons';
export declare type TagInputProps = PropsWithMetadata<{
    /**
     * List of tags which should be shown inside the component
     */
    tags: TagProps[];
    /**
     * Called every time user clicks on the input field
     */
    onInputClick?: typeof noop;
    /**
     * Called every time the input's value changes
     */
    onInputChange?: (inputStr: string) => void;
    /**
     * Called every time user presses "Enter" or comma, and onBlur of the input
     */
    onTagAdd: (inputStr: string) => void;
    /**
     * Called every time user presses cross button on the tag
     */
    onTagRemove: (tag: TagProps, index: number) => void;
    /**
     * Allows providing a custom class name to the container div
     */
    className?: string;
    /**
     * Ref to Select component to prevent onTagAdd call when option is selected
     */
    selectRef?: React.RefObject<HTMLDivElement>;
}> & Pick<InputProps, 'focused' | 'outline' | 'suffix'>;
declare const TagInput: React.ForwardRefExoticComponent<{
    /**
     * List of tags which should be shown inside the component
     */
    tags: TagProps[];
    /**
     * Called every time user clicks on the input field
     */
    onInputClick?: (() => void) | undefined;
    /**
     * Called every time the input's value changes
     */
    onInputChange?: ((inputStr: string) => void) | undefined;
    /**
     * Called every time user presses "Enter" or comma, and onBlur of the input
     */
    onTagAdd: (inputStr: string) => void;
    /**
     * Called every time user presses cross button on the tag
     */
    onTagRemove: (tag: TagProps, index: number) => void;
    /**
     * Allows providing a custom class name to the container div
     */
    className?: string | undefined;
    /**
     * Ref to Select component to prevent onTagAdd call when option is selected
     */
    selectRef?: React.RefObject<HTMLDivElement> | undefined;
} & {
    metadata?: import("@highlight-ui/utils-commons").ComponentMetadata | undefined;
} & Pick<InputProps, "outline" | "focused" | "suffix"> & React.RefAttributes<HTMLDivElement>>;
export default TagInput;
